@@ -5,26 +5,37 @@ from pyais.exceptions import (
     MissingMultipartMessageException,
     InvalidNMEAChecksum
 )
-from pyais.messages import NMEAMessage, ANY_MESSAGE
+from pyais.messages import NMEASentence, NMEASentenceFactory, AISSentence, ANY_MESSAGE
 
 
-def _assemble_messages(*args: bytes, error_if_checksum_invalid: bool = False) -> NMEAMessage:
+def _assemble_messages(
+    *args: bytes,
+    error_if_checksum_invalid: bool = False,
+) -> AISSentence:
     # Convert bytes into NMEAMessage and remember fragment_count and fragment_numbers
-    temp: typing.List[NMEAMessage] = []
+    temp: typing.List[AISSentence] = []
     frags: typing.List[int] = []
     frag_cnt: int = 1
     for msg in args:
-        nmea = NMEAMessage(msg)
-        if error_if_checksum_invalid and not nmea.is_valid:
-            raise InvalidNMEAChecksum(f'The checksum is invalid for message "{nmea.raw!r}"')
 
-        temp.append(nmea)
-        frags.append(nmea.frag_num)
-        frag_cnt = nmea.fragment_count
+        sentence = NMEASentenceFactory.produce(msg)
+
+        if error_if_checksum_invalid and not sentence.is_valid:
+            raise InvalidNMEAChecksum(f'The checksum is invalid for message "{sentence.raw!r}"')
+
+        # Ignore any other type of message
+        if sentence.TYPE == AISSentence.TYPE:
+            sentence = typing.cast(AISSentence, sentence)
+            temp.append(sentence)
+            frags.append(sentence.frag_num)
+            frag_cnt = sentence.fragment_count
+
+    if len(frags) == 0:
+        raise MissingMultipartMessageException('no AIS message to decode')
 
     # Make sure provided parts assemble a single (multiline message)
-    if len(args) > frag_cnt:
-        raise TooManyMessagesException(f"Got {len(args)} messages, but fragment count is {frag_cnt}")
+    if len(temp) > frag_cnt:
+        raise TooManyMessagesException(f"Got {len(temp)} messages, but fragment count is {frag_cnt}")
 
     # Make sure all parts of a multipart message are provided
     diff = [x for x in range(1, frag_cnt + 1) if x not in frags]
@@ -32,7 +43,7 @@ def _assemble_messages(*args: bytes, error_if_checksum_invalid: bool = False) ->
         raise MissingMultipartMessageException(f"Missing fragment numbers: {diff}")
 
     # Assemble temporary messages
-    final = NMEAMessage.assemble_from_iterable(temp)
+    final = AISSentence.assemble_from_iterable(temp)
     return final
 
 
@@ -45,6 +56,7 @@ def decode(*args: typing.Union[str, bytes], error_if_checksum_invalid: bool = Fa
     :param error_if_checksum_invalid: Raise an error if the checksum of
                                       any part is invalid. (Default=False)
     :returns: The decoded message
+    :raises UnknownMessageException: Only a small subset of all NMEA messages is supported.
     :raises InvalidNMEAChecksum: raised when the NMEA checksum is invalid.
     :raises MissingMultipartMessageException: raised when there are missing parts for multi part messages.
     :raises TooManyMessagesException: raised when more than one message is provided.
@@ -65,3 +77,15 @@ def decode(*args: typing.Union[str, bytes], error_if_checksum_invalid: bool = Fa
     parts = tuple(msg.encode('utf-8') if isinstance(msg, str) else msg for msg in args)
     nmea = _assemble_messages(*parts, error_if_checksum_invalid=error_if_checksum_invalid)
     return nmea.decode()
+
+
+def decode_nmea_line(line: bytes) -> NMEASentence:
+    """
+    Decode a single NMEA line/sentence.
+    :param line: the NMEA line/sentence to decode
+    :return: The decoded NMEA object.
+             Note that AIS messages are encapsulated inside the NMEA protocol.
+             A protocol inside a protocol sort of.
+    """
+    sentence = NMEASentenceFactory.produce(line)
+    return sentence
